<?php
/**
 * Architect Architecture Theme Customizer
 *
 * @package Architect Architecture
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function architect_architecture_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'architect_architecture_custom_controls' );

function architect_architecture_customize_register( $wp_customize ) {

	$wp_customize->get_setting( 'blogname' )->transport = 'postMessage'; 
	$wp_customize->get_setting( 'blogdescription' )->transport = 'postMessage';

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'blogname', array( 
		'selector' => '.logo .site-title a', 
	 	'render_callback' => 'architect_architecture_Customize_partial_blogname',
	)); 

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array( 
		'selector' => 'p.site-description', 
		'render_callback' => 'architect_architecture_Customize_partial_blogdescription',
	));

	// add home page setting pannel
	$wp_customize->add_panel( 'architect_architecture_panel_id', array(
		'capability' => 'edit_theme_options',
		'theme_supports' => '',
		'title' => esc_html__( 'VW Settings', 'architect-architecture' ),
		'priority' => 10,
	));

	// Layout
	$wp_customize->add_section( 'architect_architecture_left_right', array(
    	'title' => esc_html__( 'General Settings', 'architect-architecture' ),
		'panel' => 'architect_architecture_panel_id'
	) );

	$wp_customize->add_setting('architect_architecture_width_option',array(
        'default' => 'Full Width',
        'sanitize_callback' => 'architect_architecture_sanitize_choices'
	));
	$wp_customize->add_control(new Architect_Architecture_Image_Radio_Control($wp_customize, 'architect_architecture_width_option', array(
        'type' => 'select',
        'label' => esc_html__('Width Layouts','architect-architecture'),
        'description' => esc_html__('Here you can change the width layout of Website.','architect-architecture'),
        'section' => 'architect_architecture_left_right',
        'choices' => array(
            'Full Width' => esc_url(get_template_directory_uri()).'/assets/images/full-width.png',
            'Wide Width' => esc_url(get_template_directory_uri()).'/assets/images/wide-width.png',
            'Boxed' => esc_url(get_template_directory_uri()).'/assets/images/boxed-width.png',
    ))));

	$wp_customize->add_setting('architect_architecture_theme_options',array(
        'default' => 'Right Sidebar',
        'sanitize_callback' => 'architect_architecture_sanitize_choices'
	));
	$wp_customize->add_control('architect_architecture_theme_options',array(
        'type' => 'select',
        'label' => esc_html__('Post Sidebar Layout','architect-architecture'),
        'description' => esc_html__('Here you can change the sidebar layout for posts. ','architect-architecture'),
        'section' => 'architect_architecture_left_right',
        'choices' => array(
            'Left Sidebar' => esc_html__('Left Sidebar','architect-architecture'),
            'Right Sidebar' => esc_html__('Right Sidebar','architect-architecture'),
            'One Column' => esc_html__('One Column','architect-architecture'),
            'Grid Layout' => esc_html__('Grid Layout','architect-architecture')
        ),
	) );

	$wp_customize->add_setting('architect_architecture_page_layout',array(
        'default' => 'One_Column',
        'sanitize_callback' => 'architect_architecture_sanitize_choices'
	));
	$wp_customize->add_control('architect_architecture_page_layout',array(
        'type' => 'select',
        'label' => esc_html__('Page Sidebar Layout','architect-architecture'),
        'description' => esc_html__('Here you can change the sidebar layout for pages. ','architect-architecture'),
        'section' => 'architect_architecture_left_right',
        'choices' => array(
            'Left_Sidebar' => esc_html__('Left Sidebar','architect-architecture'),
            'Right_Sidebar' => esc_html__('Right Sidebar','architect-architecture'),
            'One_Column' => esc_html__('One Column','architect-architecture')
        ),
	) );

	// Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'architect_architecture_woocommerce_shop_page_sidebar', array( 'selector' => '.post-type-archive-product #sidebar', 
		'render_callback' => 'architect_architecture_customize_partial_architect_architecture_woocommerce_shop_page_sidebar', ) );

    // Woocommerce Shop Page Sidebar
	$wp_customize->add_setting( 'architect_architecture_woocommerce_shop_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'architect_architecture_switch_sanitization'
    ) );
    $wp_customize->add_control( new Architect_Architecture_Toggle_Switch_Custom_Control( $wp_customize, 'architect_architecture_woocommerce_shop_page_sidebar',array(
		'label' => esc_html__( 'Shop Page Sidebar','architect-architecture' ),
		'section' => 'architect_architecture_left_right'
    )));

    // Selective Refresh
	$wp_customize->selective_refresh->add_partial( 'architect_architecture_woocommerce_single_product_page_sidebar', array( 'selector' => '.single-product #sidebar', 
		'render_callback' => 'architect_architecture_customize_partial_architect_architecture_woocommerce_single_product_page_sidebar', ) );

    //Woocommerce Single Product page Sidebar
	$wp_customize->add_setting( 'architect_architecture_woocommerce_single_product_page_sidebar',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'architect_architecture_switch_sanitization'
    ) );
    $wp_customize->add_control( new Architect_Architecture_Toggle_Switch_Custom_Control( $wp_customize, 'architect_architecture_woocommerce_single_product_page_sidebar',array(
		'label' => esc_html__( 'Single Product Sidebar','architect-architecture' ),
		'section' => 'architect_architecture_left_right'
    )));

    // Pre-Loader
	$wp_customize->add_setting( 'architect_architecture_loader_enable',array(
        'default' => 0,
        'transport' => 'refresh',
        'sanitize_callback' => 'architect_architecture_switch_sanitization'
    ) );
    $wp_customize->add_control( new Architect_Architecture_Toggle_Switch_Custom_Control( $wp_customize, 'architect_architecture_loader_enable',array(
        'label' => esc_html__( 'Pre-Loader','architect-architecture' ),
        'section' => 'architect_architecture_left_right'
    )));

	$wp_customize->add_setting('architect_architecture_preloader_bg_color', array(
		'default'           => '#002155',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'architect_architecture_preloader_bg_color', array(
		'label'    => __('Pre-Loader Background Color', 'architect-architecture'),
		'section'  => 'architect_architecture_left_right',
	)));

	$wp_customize->add_setting('architect_architecture_preloader_border_color', array(
		'default'           => '#ffffff',
		'sanitize_callback' => 'sanitize_hex_color',
	));
	$wp_customize->add_control(new WP_Customize_Color_Control($wp_customize, 'architect_architecture_preloader_border_color', array(
		'label'    => __('Pre-Loader Border Color', 'architect-architecture'),
		'section'  => 'architect_architecture_left_right',
	)));

	// Top Bar
	$wp_customize->add_section( 'architect_architecture_top_bar' , array(
    	'title' => esc_html__( 'Top Bar', 'architect-architecture' ),
		'panel' => 'architect_architecture_panel_id'
	) );

	$wp_customize->add_setting( 'architect_architecture_search_hide_show',array(
      'default' => 1,
      'transport' => 'refresh',
      'sanitize_callback' => 'architect_architecture_switch_sanitization'
    ));  
    $wp_customize->add_control( new Architect_Architecture_Toggle_Switch_Custom_Control( $wp_customize, 'architect_architecture_search_hide_show',array(
      'label' => esc_html__( 'Show / Hide Search','architect-architecture' ),
      'section' => 'architect_architecture_top_bar'
    )));

	$wp_customize->add_setting('architect_architecture_faq_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('architect_architecture_faq_text',array(
		'label'	=> esc_html__('Add Button Text','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'FAQ', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_top_bar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('architect_architecture_faq_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('architect_architecture_faq_link',array(
		'label'	=> esc_html__('Add Button Link','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_top_bar',
		'type'=> 'url'
	));

	$wp_customize->add_setting('architect_architecture_contact_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('architect_architecture_contact_text',array(
		'label'	=> esc_html__('Add Button Text','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'CONTACT', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_top_bar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('architect_architecture_contact_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('architect_architecture_contact_link',array(
		'label'	=> esc_html__('Add Button Link','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_top_bar',
		'type'=> 'url'
	));

	$wp_customize->add_setting('architect_architecture_topbar_phone_number',array(
		'default'=> '',
		'sanitize_callback'	=> 'architect_architecture_sanitize_phone_number'
	));
	$wp_customize->add_control('architect_architecture_topbar_phone_number',array(
		'label'	=> esc_html__('Add Phone Number','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '+1 123 456 78900', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_top_bar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('architect_architecture_topbar_timing',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('architect_architecture_topbar_timing',array(
		'label'	=> esc_html__('Add Timing','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'MON - FRI: 8:00 AM - 5:00 PM', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_top_bar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('architect_architecture_topbar_btn_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('architect_architecture_topbar_btn_text',array(
		'label'	=> esc_html__('Add Button Text','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Get Quote', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_top_bar',
		'type'=> 'text'
	));

	$wp_customize->add_setting('architect_architecture_topbar_btn_link',array(
		'default'=> '',
		'sanitize_callback'	=> 'esc_url_raw'
	));
	$wp_customize->add_control('architect_architecture_topbar_btn_link',array(
		'label'	=> esc_html__('Add Button Link','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'www.example-info.com', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_top_bar',
		'type'=> 'url'
	));

	//Slider
	$wp_customize->add_section( 'architect_architecture_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'architect-architecture' ),
		'panel' => 'architect_architecture_panel_id'
	) );

	$wp_customize->add_setting( 'architect_architecture_slider_hide_show',array(
      'default' => 0,
      'transport' => 'refresh',
      'sanitize_callback' => 'architect_architecture_switch_sanitization'
    ));  
    $wp_customize->add_control( new Architect_Architecture_Toggle_Switch_Custom_Control( $wp_customize, 'architect_architecture_slider_hide_show',array(
      'label' => esc_html__( 'Show / Hide Slider','architect-architecture' ),
      'section' => 'architect_architecture_slidersettings'
    )));

     //Selective Refresh
    $wp_customize->selective_refresh->add_partial('architect_architecture_slider_hide_show',array(
		'selector'        => '.slider-btn a',
		'render_callback' => 'architect_architecture_customize_partial_architect_architecture_slider_hide_show',
	));

	for ( $count = 1; $count <= 4; $count++ ) {
		$wp_customize->add_setting( 'architect_architecture_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'architect_architecture_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'architect_architecture_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'architect-architecture' ),
			'description' => __('Slider image size (1500 x 650)','architect-architecture'),
			'section'  => 'architect_architecture_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}

	$wp_customize->add_setting('architect_architecture_slider_button_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('architect_architecture_slider_button_text',array(
		'label'	=> __('Add Slider Button Text','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => __( 'Read More', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_slidersettings',
		'type'=> 'text'
	));

	//content layout
	$wp_customize->add_setting('architect_architecture_slider_content_option',array(
        'default' => 'Center',
        'sanitize_callback' => 'architect_architecture_sanitize_choices'
	));
	$wp_customize->add_control(new Architect_Architecture_Image_Radio_Control($wp_customize, 'architect_architecture_slider_content_option', array(
        'type' => 'select',
        'label' => __('Slider Content Layouts','architect-architecture'),
        'section' => 'architect_architecture_slidersettings',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/slider-content1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/slider-content2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/slider-content3.png',
    ))));

    //Slider excerpt
	$wp_customize->add_setting( 'architect_architecture_slider_excerpt_number', array(
		'default'              => 30,
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'architect_architecture_sanitize_number_range'
	) );
	$wp_customize->add_control( 'architect_architecture_slider_excerpt_number', array(
		'label'       => esc_html__( 'Slider Excerpt length','architect-architecture' ),
		'section'     => 'architect_architecture_slidersettings',
		'type'        => 'range',
		'settings'    => 'architect_architecture_slider_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

	//Opacity
	$wp_customize->add_setting('architect_architecture_slider_opacity_color',array(
      'default'              => 0.5,
      'sanitize_callback' => 'architect_architecture_sanitize_choices'
	));

	$wp_customize->add_control( 'architect_architecture_slider_opacity_color', array(
	'label'       => esc_html__( 'Slider Image Opacity','architect-architecture' ),
	'section'     => 'architect_architecture_slidersettings',
	'type'        => 'select',
	'settings'    => 'architect_architecture_slider_opacity_color',
	'choices' => array(
      '0' =>  esc_attr('0','architect-architecture'),
      '0.1' =>  esc_attr('0.1','architect-architecture'),
      '0.2' =>  esc_attr('0.2','architect-architecture'),
      '0.3' =>  esc_attr('0.3','architect-architecture'),
      '0.4' =>  esc_attr('0.4','architect-architecture'),
      '0.5' =>  esc_attr('0.5','architect-architecture'),
      '0.6' =>  esc_attr('0.6','architect-architecture'),
      '0.7' =>  esc_attr('0.7','architect-architecture'),
      '0.8' =>  esc_attr('0.8','architect-architecture'),
      '0.9' =>  esc_attr('0.9','architect-architecture')
	),
	));

	//Slider height
	$wp_customize->add_setting('architect_architecture_slider_height',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('architect_architecture_slider_height',array(
		'label'	=> __('Slider Height','architect-architecture'),
		'description'	=> __('Specify the slider height (px).','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => __( '500px', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_slidersettings',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'architect_architecture_slider_speed', array(
		'default'  => 4000,
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'architect_architecture_slider_speed', array(
		'label' => esc_html__('Slider Transition Speed','architect-architecture'),
		'section' => 'architect_architecture_slidersettings',
		'type'  => 'text',
	) );

	// Portfolio
	$wp_customize->add_section('architect_architecture_portfolio',array(
		'title'	=> __('Portfolio Section','architect-architecture'),
		'description' => __('Add the content and select the post category to display post.','architect-architecture'),
		'panel' => 'architect_architecture_panel_id',
	));

	$wp_customize->add_setting('architect_architecture_portfolio_heading',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('architect_architecture_portfolio_heading',array(
		'label'	=> esc_html__('Portfolio Section Heading','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Our Portfolio', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_portfolio',
		'type'=> 'text'
	));

	$wp_customize->add_setting('architect_architecture_portfolio_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('architect_architecture_portfolio_text',array(
		'label'	=> esc_html__('Portfolio Section Text','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Lorem Ipsum has been the industry standard dummy text ever since the 1500s', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_portfolio',
		'type'=> 'text'
	));

	$categories = get_categories();
		$cat_posts = array();
			$i = 0;
			$cat_posts[]='Select';
		foreach($categories as $category){
			if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('architect_architecture_portfolio_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'architect_architecture_sanitize_choices',
	));
	$wp_customize->add_control('architect_architecture_portfolio_category',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display Portfolio','architect-architecture'),
		'section' => 'architect_architecture_portfolio',
	));

	//Blog Post

	$wp_customize->add_panel( 'architect_architecture_blog_post_parent_panel', array(
		'title' => esc_html__( 'Blog Post Settings', 'architect-architecture' ),
		'panel' => 'architect_architecture_panel_id',
		'priority' => 20,
	));

	// Add example section and controls to the middle (second) panel
	$wp_customize->add_section( 'architect_architecture_post_settings', array(
		'title' => esc_html__( 'Post Settings', 'architect-architecture' ),
		'panel' => 'architect_architecture_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('architect_architecture_toggle_postdate', array( 
		'selector' => '.post-main-box h2 a', 
		'render_callback' => 'architect_architecture_Customize_partial_architect_architecture_toggle_postdate', 
	));

	$wp_customize->add_setting( 'architect_architecture_toggle_postdate',array(
        'default' => 1,
        'transport' => 'refresh',
        'sanitize_callback' => 'architect_architecture_switch_sanitization'
    ) );
    $wp_customize->add_control( new Architect_Architecture_Toggle_Switch_Custom_Control( $wp_customize, 'architect_architecture_toggle_postdate',array(
        'label' => esc_html__( 'Post Date','architect-architecture' ),
        'section' => 'architect_architecture_post_settings'
    )));

    $wp_customize->add_setting( 'architect_architecture_toggle_author',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'architect_architecture_switch_sanitization'
    ) );
    $wp_customize->add_control( new Architect_Architecture_Toggle_Switch_Custom_Control( $wp_customize, 'architect_architecture_toggle_author',array(
		'label' => esc_html__( 'Author','architect-architecture' ),
		'section' => 'architect_architecture_post_settings'
    )));

    $wp_customize->add_setting( 'architect_architecture_toggle_comments',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'architect_architecture_switch_sanitization'
    ) );
    $wp_customize->add_control( new Architect_Architecture_Toggle_Switch_Custom_Control( $wp_customize, 'architect_architecture_toggle_comments',array(
		'label' => esc_html__( 'Comments','architect-architecture' ),
		'section' => 'architect_architecture_post_settings'
    )));

    $wp_customize->add_setting( 'architect_architecture_toggle_tags',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'architect_architecture_switch_sanitization'
	));
    $wp_customize->add_control( new Architect_Architecture_Toggle_Switch_Custom_Control( $wp_customize, 'architect_architecture_toggle_tags', array(
		'label' => esc_html__( 'Tags','architect-architecture' ),
		'section' => 'architect_architecture_post_settings'
    )));

    $wp_customize->add_setting( 'architect_architecture_excerpt_number', array(
		'default'              => 30,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'architect_architecture_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'architect_architecture_excerpt_number', array(
		'label'       => esc_html__( 'Excerpt length','architect-architecture' ),
		'section'     => 'architect_architecture_post_settings',
		'type'        => 'range',
		'settings'    => 'architect_architecture_excerpt_number',
		'input_attrs' => array(
			'step'             => 5,
			'min'              => 0,
			'max'              => 50,
		),
	) );

    $wp_customize->add_setting('architect_architecture_excerpt_settings',array(
        'default' => 'Excerpt',
        'transport' => 'refresh',
        'sanitize_callback' => 'architect_architecture_sanitize_choices'
	));
	$wp_customize->add_control('architect_architecture_excerpt_settings',array(
        'type' => 'select',
        'label' => esc_html__('Post Content','architect-architecture'),
        'section' => 'architect_architecture_post_settings',
        'choices' => array(
        	'Content' => esc_html__('Content','architect-architecture'),
            'Excerpt' => esc_html__('Excerpt','architect-architecture'),
            'No Content' => esc_html__('No Content','architect-architecture')
        ),
	) );

    // Button Settings
	$wp_customize->add_section( 'architect_architecture_button_settings', array(
		'title' => esc_html__( 'Button Settings', 'architect-architecture' ),
		'panel' => 'architect_architecture_blog_post_parent_panel',
	));

	$wp_customize->add_setting( 'architect_architecture_button_border_radius', array(
		'default'              => 5,
		'type'                 => 'theme_mod',
		'transport' 		   => 'refresh',
		'sanitize_callback'    => 'architect_architecture_sanitize_number_range',
		'sanitize_js_callback' => 'absint',
	) );
	$wp_customize->add_control( 'architect_architecture_button_border_radius', array(
		'label'       => esc_html__( 'Button Border Radius','architect-architecture' ),
		'section'     => 'architect_architecture_button_settings',
		'type'        => 'range',
		'input_attrs' => array(
			'step'             => 1,
			'min'              => 1,
			'max'              => 50,
		),
	) );

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('architect_architecture_button_text', array( 
		'selector' => '.post-main-box .more-btn a', 
		'render_callback' => 'architect_architecture_Customize_partial_architect_architecture_button_text', 
	));

    $wp_customize->add_setting('architect_architecture_button_text',array(
		'default'=> esc_html__('Read More','architect-architecture'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('architect_architecture_button_text',array(
		'label'	=> esc_html__('Add Button Text','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Read More', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_button_settings',
		'type'=> 'text'
	));

	// Related Post Settings
	$wp_customize->add_section( 'architect_architecture_related_posts_settings', array(
		'title' => esc_html__( 'Related Posts Settings', 'architect-architecture' ),
		'panel' => 'architect_architecture_blog_post_parent_panel',
	));

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('architect_architecture_related_post_title', array( 
		'selector' => '.related-post h3', 
		'render_callback' => 'architect_architecture_Customize_partial_architect_architecture_related_post_title', 
	));

    $wp_customize->add_setting( 'architect_architecture_related_post',array(
		'default' => 1,
		'transport' => 'refresh',
		'sanitize_callback' => 'architect_architecture_switch_sanitization'
    ) );
    $wp_customize->add_control( new Architect_Architecture_Toggle_Switch_Custom_Control( $wp_customize, 'architect_architecture_related_post',array(
		'label' => esc_html__( 'Related Post','architect-architecture' ),
		'section' => 'architect_architecture_related_posts_settings'
    )));

    $wp_customize->add_setting('architect_architecture_related_post_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('architect_architecture_related_post_title',array(
		'label'	=> esc_html__('Add Related Post Title','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Related Post', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_related_posts_settings',
		'type'=> 'text'
	));

   	$wp_customize->add_setting('architect_architecture_related_posts_count',array(
		'default'=> 3,
		'sanitize_callback'	=> 'architect_architecture_sanitize_number_absint'
	));
	$wp_customize->add_control('architect_architecture_related_posts_count',array(
		'label'	=> esc_html__('Add Related Post Count','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( '3', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_related_posts_settings',
		'type'=> 'number'
	));

	//Footer Text
	$wp_customize->add_section('architect_architecture_footer',array(
		'title'	=> esc_html__('Footer Settings','architect-architecture'),
		'panel' => 'architect_architecture_panel_id',
	));	

	//Selective Refresh
	$wp_customize->selective_refresh->add_partial('architect_architecture_footer_text', array( 
		'selector' => '.copyright p', 
		'render_callback' => 'architect_architecture_Customize_partial_architect_architecture_footer_text', 
	));
	
	$wp_customize->add_setting('architect_architecture_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('architect_architecture_footer_text',array(
		'label'	=> esc_html__('Copyright Text','architect-architecture'),
		'input_attrs' => array(
            'placeholder' => esc_html__( 'Copyright 2020, .....', 'architect-architecture' ),
        ),
		'section'=> 'architect_architecture_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting('architect_architecture_copyright_alingment',array(
        'default' => 'center',
        'sanitize_callback' => 'architect_architecture_sanitize_choices'
	));
	$wp_customize->add_control(new Architect_Architecture_Image_Radio_Control($wp_customize, 'architect_architecture_copyright_alingment', array(
        'type' => 'select',
        'label' => esc_html__('Copyright Alignment','architect-architecture'),
        'section' => 'architect_architecture_footer',
        'settings' => 'architect_architecture_copyright_alingment',
        'choices' => array(
            'left' => esc_url(get_template_directory_uri()).'/assets/images/copyright1.png',
            'center' => esc_url(get_template_directory_uri()).'/assets/images/copyright2.png',
            'right' => esc_url(get_template_directory_uri()).'/assets/images/copyright3.png'
    ))));

    $wp_customize->add_setting( 'architect_architecture_hide_show_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'architect_architecture_switch_sanitization'
    ));  
    $wp_customize->add_control( new Architect_Architecture_Toggle_Switch_Custom_Control( $wp_customize, 'architect_architecture_hide_show_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','architect-architecture' ),
      	'section' => 'architect_architecture_footer'
    )));

     //Selective Refresh
	$wp_customize->selective_refresh->add_partial('architect_architecture_scroll_to_top_icon', array( 
		'selector' => '.scrollup i', 
		'render_callback' => 'architect_architecture_Customize_partial_architect_architecture_scroll_to_top_icon', 
	));

    $wp_customize->add_setting('architect_architecture_scroll_top_alignment',array(
        'default' => 'Right',
        'sanitize_callback' => 'architect_architecture_sanitize_choices'
	));
	$wp_customize->add_control(new Architect_Architecture_Image_Radio_Control($wp_customize, 'architect_architecture_scroll_top_alignment', array(
        'type' => 'select',
        'label' => esc_html__('Scroll To Top','architect-architecture'),
        'section' => 'architect_architecture_footer',
        'settings' => 'architect_architecture_scroll_top_alignment',
        'choices' => array(
            'Left' => esc_url(get_template_directory_uri()).'/assets/images/layout1.png',
            'Center' => esc_url(get_template_directory_uri()).'/assets/images/layout2.png',
            'Right' => esc_url(get_template_directory_uri()).'/assets/images/layout3.png'
    ))));
}

add_action( 'customize_register', 'architect_architecture_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class Architect_Architecture_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Architect_Architecture_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Architect_Architecture_Customize_Section_Pro( $manager,'architect_architecture_go_pro', array(
			'priority'   => 1,
			'title'    => esc_html__( 'ARCHITECTURE PRO', 'architect-architecture' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'architect-architecture' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/architecture-wordpress-theme/'),
		) )	);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'architect-architecture-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'architect-architecture-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
Architect_Architecture_Customize::get_instance();